%function fly_eval_probit(varargin)
% evaluation script for fly RNA.
% we load the raw data (each channel separately).
% then extract a dataset
% from the meta_info.txt and dapple file: 
% Gdata, Cy3, 532 nm <> Male after adjusting for dye swap
% Rdata, Cy5, 635 nm <> Female after adjusting for dye swap
%
% (C) P. Sykacek 2010

addpath('../mlablib/');    

% old std. paths
%addpath('~/sciwrk/mlbsrc/resultfltr/');    
%addpath('~/sciwrk/mlbsrc/helpers/');
%addpath('~/sciwrk/mlbsrc/probitem/');
%addpath('~/sciwrk/mlbsrc/slide_normalization/');
%addpath('~/sciwrk/mlbsrc/mca_helpers/');
%addpath('~/sciwrk/mlbsrc/testing/');

%if 0
effdescnam='bfs_fly2_lc_raweffdesc.tsv';
% files containing the protocol data:
sptfnams(1).spotter='emprobit_loc';
sptfnams(1).titlepart='Location Removal';
%       !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! location only
sptfnams(1).Rfnam='bfs_fly2_lc_rawlogR.tsv';
sptfnams(1).Gfnam='bfs_fly2_lc_rawlogG.tsv';

ttlsz=18;
plot_markersize=10;
plot_linewidth=2;

disp('load data')
% now we load the data:
% first we get the effects
[hdr, effects]=scan_fspma(effdescnam);
tmpid=effects(:,1); % first column names temp levels.
alltmp=unique(tmpid);
temperatures=['Hyb 47 C    '; 'Hyb 49 C    '; 'Hyb 50 C (a)'; 'Hyb 50 C (b)'; 'Hyb 51 C    '; 'Hyb 52 C    ';'Hyb 54 C    '; 'Hyb 56 C    '];
ntmp=length(alltmp);
% now the data
protdata=[];
ndt=1;
nsptrs=length(sptfnams);

% subsample for test purpouses (code functionality):
[gnames, allRdata]=scan_fspma(sptfnams(1).Rfnam);
ngenes=length(gnames);
idsubsel=randperm(ngenes);
idsubsel=idsubsel(1:100);

% flag - set 1 for test purpouses (i.e. code functionality)
dosubsel=0;
% generate data:
ndt=1;
for n=1:length(sptfnams);
    % read expression values
    [gnames, allRdata]=scan_fspma(sptfnams(n).Rfnam);
    [gnames, allGdata]=scan_fspma(sptfnams(n).Gfnam);
    if dosubsel==1 % subset selection for test purpouse
        gnames=gnames(idsubsel);
        allRdata=allRdata(:,idsubsel);
        allGdata=allGdata(:,idsubsel);
    end
    sptfnams(n).protdatadx=[];
    % now we extract the two channels for each temperature.
    for m=1:ntmp
        thisdx=find(tmpid==alltmp(m));
        Rdata=allRdata(thisdx,:);
        Gdata=allGdata(thisdx,:);
        Rdt=[Rdata, ones(size(Rdata, 1), 1)];
        Gdt=[Gdata, 2*ones(size(Gdata, 1), 1)];
        nrws=size(Rdt,1)+size(Gdt,1);
        ncls=size(Rdt,2);
        tran=[Rdt, Gdt]';
        tran=tran(:);
        tran=reshape(tran, ncls, nrws)';
        protdata(ndt).tran=tran;
        protdata(ndt).Rdata=Rdata;
        protdata(ndt).Rspec='Female';
        protdata(ndt).Gdata=Gdata;
        protdata(ndt).Gspec='Male';        
        protdata(ndt).spotter=sptfnams(n).spotter;
        protdata(ndt).temptxt=temperatures(alltmp(m),:);
        % add reference to spotter record
        sptfnams(n).protdatadx=[sptfnams(n).protdatadx, ndt];
        ndt=ndt+1;
    end
end
ngenes=length(gnames);
allgenenames=gnames;

% generate subsets
subs(1).name='Random selection of 500 genes per 20 \% channel amplitude quantil.';
subs(1).nrep=100;
if dosubsel==1 % subset selection for test purpouse
    subs(1).sspec=[0.2, 5; 0.4, 5; 0.6, 5; 0.8, 5; 1, 5];
else
    subs(1).sspec=[0.2, 500; 0.4, 500; 0.6, 500; 0.8, 500; 1, 500];
end
subs(1).op='amp';
subs(2).name='Random selection of 500 genes per 20 \% channel log ratio quantil.';
subs(2).nrep=100;
if dosubsel==1 % subset selection for test purpouse
    subs(2).sspec=[0.2, 5; 0.4, 5; 0.6, 5; 0.8, 5; 1, 5];
else
    subs(2).sspec=[0.2, 500; 0.4, 500; 0.6, 500; 0.8, 500; 1, 500];
end
subs(2).op='rt';
subs(3).name='Selection of a random number of genes per 20 \% channel amplitude quantil.';
subs(3).nrep=1;
quantmaxgenes=floor(0.2*ngenes);
for n=1:100
    cspec=[[0.2;0.4;0.6;0.8;1], ones(5,1)];
    for m=1:5
        cspec(m,2)=max(1,min(floor(rand*quantmaxgenes*0.2)+1, quantmaxgenes));
    end
    subs(3).sspec{n}=cspec;
end
subs(3).op='amp';
subs(4).name='Selection of a random number of genes per 20 \% channel log ratio quantil.';
subs(4).nrep=1;
quantmaxgenes=floor(0.2*ngenes);
for n=1:100
    cspec=[[0.2;0.4;0.6;0.8;1], ones(5,1)];
    for m=1:5
        cspec(m,2)=max(1,min(floor(rand*quantmaxgenes*0.2)+1, quantmaxgenes));
    end
    subs(4).sspec{n}=cspec;
end
subs(4).op='rt';

% algorithm parameters for evaluations
folds=1;
maxdiff=0.001;
maxcnt=100;
latprec=1;
prioprec=0;
pthrs=0.05;

% temperature index used for guiding random sampling
spectmp=4; % one of the 50C temperatures
% agregation fucntion:
agfunc=@sum;
% we do now calculate for every temperature all evaluation measures for 
% all random selections
nsim=length(subs);
ntmp=length(protdata);
for tct=1:ntmp
    protdata(tct).allhs=zeros(4, 100);
    protdata(tct).allsignone=zeros(4, 100);
    protdata(tct).allsigbonf=zeros(4, 100);
    protdata(tct).allsigfdr=zeros(4, 100);
end
% if (0)
% evaluate all random splits
for sct=1:nsim
    if iscell(subs(sct).sspec)
        nspec=length(subs(sct).sspec);
        for spct=1:nspec
            if mod(spct, 10)==0
                disp(sprintf('Subsampling approach %1.0f, iteration: %1.0f', sct, spct));
            end
            % get random sample
            currspec=subs(sct).sspec{spct};
            [data]=chan2vals(protdata(spectmp).Rdata, protdata(spectmp).Gdata, subs(sct).op);
            [datacols, seldx]=subsamplegeneids(data, agfunc, currspec);
            % get labelled subset of genes (the same genes are used by all
            % temperatures!!)
            datacols=[datacols, size(protdata(spectmp).tran, 2)];
            % loop over all temperatures
            for tct=1:ntmp
                tran=protdata(tct).tran(:,datacols);
                % evaluate random sample by EM probit
                subsets=num2cell([1:size(tran,2)-1]);
                [Pclass, targets, logevids, subsprobs]=evalprobitem(tran, latprec, maxdiff, maxcnt, subsets, folds, prioprec);
                % store the sum of all gene wise log evidences
                protdata(tct).allhs(sct,spct)=sum(logevids);
                % get anova pvalues
                [allp]=mca21w_anova(tran, 'none');
                protdata(tct).allsignone(sct, spct)=sum(allp<pthrs);
                protdata(tct).allsigbonf(sct, spct)=sum(pvaladjust(allp, 'bonferroni')<pthrs);
                protdata(tct).allsigfdr(sct, spct)=sum(pvaladjust(allp, 'fdr')<pthrs);
            end
        end
    else
        currspec=subs(sct).sspec;
        for spct=1:subs(sct).nrep
            if mod(spct, 10)==0
                disp(sprintf('Subsampling approach %1.0f, iteration: %1.0f', sct, spct));
            end
            % get random sample
            [data]=chan2vals(protdata(spectmp).Rdata, protdata(spectmp).Gdata, subs(sct).op);
            [datacols, seldx]=subsamplegeneids(data, agfunc, currspec);
            % get labelled subset of genes (the same genes are used by all
            % temperatures!!)
            datacols=[datacols, size(protdata(spectmp).tran, 2)];
            % loop over all temperatures
            for tct=1:ntmp
                tran=protdata(tct).tran(:,datacols);
                % evaluate random sample by EM probit
                subsets=num2cell([1:size(tran,2)-1]);
                [Pclass, targets, logevids, subsprobs]=evalprobitem(tran, latprec, maxdiff, maxcnt, subsets, folds, prioprec);
                % store the sum of all gene wise log evidences
                protdata(tct).allhs(sct,spct)=sum(logevids);
                % and get anova pvalues
                [allp]=mca21w_anova(tran, 'none');
                protdata(tct).allsignone(sct, spct)=sum(allp<pthrs);
                protdata(tct).allsigbonf(sct, spct)=sum(pvaladjust(allp, 'bonferroni')<pthrs);
                protdata(tct).allsigfdr(sct, spct)=sum(pvaladjust(allp, 'fdr')<pthrs);
            end
        end
    end
end
%end
%load randsampleres
% end
% specification of sample split (we seperate data into five quantils and
% split each quantil evenly in two subsamples.)
evensplit=[0.2; 0.4; 0.6; 0.8; 1];
% evaluating a sample split based on amplitude
% get random sample
[data]=chan2vals(protdata(spectmp).Rdata, protdata(spectmp).Gdata, 'amp');
[amp_datacolseval, seldx]=subsamplegeneids(data, agfunc, evensplit);
allcols=ones(1,size(data,2));
allcols(amp_datacolseval)=0;
amp_datacolstest=find(allcols);
% loop over temperatures
for tct=1:ntmp
    evaltran=protdata(tct).tran(:,[amp_datacolseval, size(protdata(tct).tran,2)]);
    testtran=protdata(tct).tran(:,[amp_datacolstest, size(protdata(tct).tran,2)]);
    % evaluate random sample
    subsets=num2cell([1:size(evaltran,2)-1]);
    % EM probit on evaltran
    [Pclass, targets, logevids, subsprobs]=evalprobitem(evaltran, latprec, maxdiff, maxcnt, subsets, folds, prioprec);
    % store the sum of all gene wise log evidences
    protdata(tct).ampsplitlhs(1)=sum(logevids);
    % and get anova pvalues
    % significance testing on testtran
    [allp]=mca21w_anova(testtran, 'none');
    protdata(tct).amp_testpvals=allp;
    protdata(tct).ampsplitnone(1)=sum(allp<pthrs);
    protdata(tct).ampsplitbonf(1)=sum(pvaladjust(allp, 'bonferroni')<pthrs);
    protdata(tct).ampsplitfdr(1)=sum(pvaladjust(allp, 'fdr')<pthrs);
    % and now vice versa:
    subsets=num2cell([1:size(testtran,2)-1]);
    % EM probit on testtran
    [Pclass, targets, logevids, subsprobs]=evalprobitem(testtran, latprec, maxdiff, maxcnt, subsets, folds, prioprec);
    % store the sum of all gene wise log evidences
    protdata(tct).ampsplitlhs(2)=sum(logevids);
    % and get anova pvalues
    % significance testing on evaltran
    [allp]=mca21w_anova(evaltran, 'none');
    protdata(tct).amp_evalpvals=allp;
    protdata(tct).ampsplitnone(2)=sum(allp<pthrs);
    protdata(tct).ampsplitbonf(2)=sum(pvaladjust(allp, 'bonferroni')<pthrs);
    protdata(tct).ampsplitfdr(2)=sum(pvaladjust(allp, 'fdr')<pthrs);
end
% evaluating a sample split based on log ratio
% get random sample
[data]=chan2vals(protdata(spectmp).Rdata, protdata(spectmp).Gdata, 'rt');
[rt_datacolseval, seldx]=subsamplegeneids(data, agfunc, evensplit);
allcols=ones(1,size(data,2));
allcols(rt_datacolseval)=0;
rt_datacolstest=find(allcols);
% loop over temperatures
for tct=1:ntmp
    evaltran=protdata(tct).tran(:,[rt_datacolseval, size(protdata(tct).tran,2)]);
    testtran=protdata(tct).tran(:,[rt_datacolstest, size(protdata(tct).tran,2)]);
    % evaluate random sample
    subsets=num2cell([1:size(evaltran,2)-1]);
    % EM probit on evaltran
    [Pclass, targets, logevids, subsprobs]=evalprobitem(evaltran, latprec, maxdiff, maxcnt, subsets, folds, prioprec);
    % store the sum of all gene wise log evidences
    protdata(tct).rtsplitlhs(1)=sum(logevids);
    % and get anova pvalues
    % significance testing on testtran
    [allp]=mca21w_anova(testtran, 'none');
    protdata(tct).rt_testpvals=allp;
    protdata(tct).rtsplitnone(1)=sum(allp<pthrs);
    protdata(tct).rtsplitbonf(1)=sum(pvaladjust(allp, 'bonferroni')<pthrs);
    protdata(tct).rtsplitfdr(1)=sum(pvaladjust(allp, 'fdr')<pthrs);
    % and now vice versa:
    subsets=num2cell([1:size(testtran,2)-1]);
    % EM probit on testtran
    [Pclass, targets, logevids, subsprobs]=evalprobitem(testtran, latprec, maxdiff, maxcnt, subsets, folds, prioprec);
    % store the sum of all gene wise log evidences
    protdata(tct).rtsplitlhs(2)=sum(logevids);
    % and get anova pvalues
    % significance testing on evaltran
    [allp]=mca21w_anova(evaltran, 'none');
    protdata(tct).rt_evalpvals=allp;
    protdata(tct).rtsplitnone(2)=sum(allp<pthrs);
    protdata(tct).rtsplitbonf(2)=sum(pvaladjust(allp, 'bonferroni')<pthrs);
    protdata(tct).rtsplitfdr(2)=sum(pvaladjust(allp, 'fdr')<pthrs);
end

save randsampleres