function [P]=bprb_lgevids2prob(lgE, Pmethod, quantile)
% function [P]=bprb_lgevids2prob(lgE, Pmethod, quantile)
% estimates model probabilities from log evidences.
% lgE:	    log model evidences [n_mcmc, nmodels]
% Pmethod:  estimation method of the probabilities.
%           'a' - arithmetic mean, 'g' - geometric mean
%	    'm' - median
% quantile: if present this parameter specifies the 
%           quantiles to be ignored in the estimation.
%           i.e. if quantile = 0.05, all data outside
%           the 0.05 and 0.95 are set to the values
%           corresponding to the respective quantile.
%           This has obviously no effect on the median 
%           estimate.
% P:        probabilities corresponding to the log evidences.
%
% (C) P. Sykacek 2003
%# scalar n_mcmc nmodels do_robust quantile nm lq hq lqpos hqpos n
Pmthd=Pmethod; % speed up!

%if Pmthd=='a'
% callstrg='Calculating the arithmetic mean of model probabilities';
%elseif Pmthd=='g' 
% callstrg='Calculating the geometric mean of model probabilities';
%else
% callstrg='Calculating model probabilities using the median log evidence';
%end
%disp(callstrg);

if nargin < 3
quantile=0.05;
end

[n_mcmc, nmodels]=size(lgE);
do_robust=nargin==3;
% clip lgE values for robustness of the estimate
if (Pmthd=='a' | Pmthd=='g') & do_robust
 nm=1;
 lqpos=floor(n_mcmc*quantile)+1;
 hqpos=floor(n_mcmc*(1-quantile));
 while nm <= nmodels
  [vals, idx]=sort(lgE(:,nm));
  lq=vals(lqpos);
  hq=vals(hqpos);
  lgE(idx(1:lqpos),nm)=lq;
  lgE(idx(hqpos:n_mcmc),nm)=hq;
  nm=nm+1;
 end
end    
% finally we convert the log evidence into the probability P.
P=zeros(1, nmodels);
if Pmthd=='a' % arithmetic mean
% first add probabilities from every sample of the log evidences.
 n=1;
 while n <= n_mcmc
  if mod(n, 100) == 0, disp(n); end
  nm=1;
  while nm <= nmodels
   P(nm)=P(nm)+1./sum(exp(lgE(n,:)-lgE(n,nm)));
   nm=nm+1;
  end
  n=n+1;
 end
% and then renormalize
 P=P/n_mcmc;
else % geometric mean or median.
 if Pmthd=='g' 
  lgE=mean(lgE);
 else
  lgE=median(lgE);
 end
 nm=1;
 while nm <= nmodels
  P(nm)=1./sum(exp(lgE-lgE(nm)));
  nm=nm+1;
 end    
end