function [data]=chan2vals(Rchan, Gchan, mode)
% function [data]=chan2vals(Rchan, Gchan, mode)
% depending on mode, transforms channel values into log ratios or log
% amplitudes.
% IN
% Rchan, Gchan: Channel values, both being [nsamples x ngenes] matrices.
% mode:         default parameter (if missing set to 'logrt') possible
%               values:
%                       'logrt': channel matrices are intensities and
%                       transformed to log ratios.
%                       'logamp': channel matrices are intensities and
%                       transformed to log amplitudes
%                       'rt': channel matrices are log intensities and
%                       converted to log ratios.
%                       'amp': channel matrices are log intensities and
%                       converted to log amplitudes.
% OUT
% data:         transformed output values, being one [nsamples x ngenes]
%               matrix
%
% (C) P. Sykacek 2008 <peter@sykacek.net>

if nargin < 3
    mode='logrt';
end
if strcmp(mode, 'logrt')
    Rchan(Rchan < eps) = eps;
    Gchan(Gchan < eps) = eps;
    Rchan=log2(Rchan);
    Gchan=log2(Gchan);
    data=Rchan-Gchan;
elseif strcmp(mode, 'logamp')
    Rchan(Rchan < eps) = eps;
    Gchan(Gchan < eps) = eps;
    Rchan=log2(Rchan);
    Gchan=log2(Gchan);
    data=0.5*(Rchan+Gchan);
elseif strcmp(mode, 'rt')
    data=Rchan-Gchan;
else
    data=0.5*(Rchan+Gchan);
end