function [shrdnums, diffnums]=compsrtnums(sn1, sn2)
% function [shrdnums, diffnums]=compsrtnums(sn1, sn2)
% searches for common entries in sn1 and sn2 and builds
% the vectors shrdnums and diffnums containing shared 
% entries and entries found only in one of the two.
%
% IN
% sn1, sn2: vectors or matrices of numbers
% OUT
% shrdnums: entries found in sn1 and sn2 (intersection)
% diffnums: entries found in either of the two input matrices but not in
%           the other (union minus intersection)
%
% (C) P. Sykacek 2008 <peter@sykacek.net>
sn1=[unique(sn1(:))];
sn2=[unique(sn2(:))];
mxlen=length(sn1)+length(sn2);
shrdnums=nan*ones(mxlen, 1);
diffnums=nan*ones(mxlen, 1);
l1=length(sn1);
l2=length(sn2);
c1=1;
c2=1;
shrdx=1;
diffdx=1;
dochk=~isempty(sn1) && ~isempty(sn2);
if ~dochk
    shrdnums=[];
    diffnums=unique([sn1;sn2]);
else
    while dochk  %% separate into shared and differing entries
        if sn1(c1) == sn2(c2)
            shrdnums(shrdx)=sn1(c1);
            shrdx=shrdx+1;
            c1=c1+1;
            c2=c2+1;
        elseif sn1(c1) < sn2(c2)
            diffnums(diffdx)=sn1(c1);
            diffdx=diffdx+1;
            c1=c1+1;
        elseif sn1(c1) > sn2(c2)
            diffnums(diffdx)=sn2(c2);
            diffdx=diffdx+1;
            c2=c2+1;
        end
        dochk=(c1 <= l1) && (c2 <= l2);
    end
    nd1=l1-c1;
    if nd1>=0
       diffnums(diffdx:(diffdx+nd1))=sn1(c1:l1);
    end
    nd2=l2-c2;
    if nd2>=0
       diffnums(diffdx:(diffdx+nd2))=sn2(c2:l2);
    end
end
shrdnums=shrdnums(find(~isnan(shrdnums)));
diffnums=diffnums(find(~isnan(diffnums)));
