function [allp]=mca21w_anova(tran, padjust)
% function [allp]=mca21w_anova(tran, padjust)
% wraper which allows for the matlab statistics toolbox one way anova to be
% used for analysing microarray data.
% IN
% tran:     a labelled fspma compatible matrix of microarray data.
%           [no samples x (no genes +1)] matrix of normalised expression
%           values. The last column contains labels which indicate the
%           grouping of different effect levels.
% padjust:  specifier for the p-value adjustment to be used. see function
%           .../mlbsrc/testing/pvaladjust.m for further information on
%           this.
% OUT
% allp:     a [1 x no genes] vector of p-values illustrating the
%           significance level of he null hypothesis of the corresponding
%           gene, that all levels are modelled with the same mean.
%
% (C) P. Sykacek 2008 <peter@sykacek.net>
groups=tran(:,size(tran, 2));
ngenes=size(tran,2)-1;
allp=ones(1, ngenes);
for n=1:ngenes
    % call statistics toolbox n-way anova (potential lack of balanced
    % designs reqires this).
    allp(n)=anovan(tran(:,n), groups, 'display', 'off');
end
allp=pvaladjust(allp, padjust);