function [header, data]=scan_fspma(fname)
% function [header, data]=scan_fspma(fname)
% reads in raw data generated by fspma.wrapper (the R library).
% IN:
% fname -  file name to be read. Note that there are two raw files 
%          generated by fspma.wrapper: one contains data, the other 
%          provides information about the effects in the experiment.
% OUT:  
% header - contains the first row of the file, wich is either the
%          names of the transcripts in case of a data file or a
%          description of each effect in case of a effects file.
% data -   contains the numerical data, which in case of a micro
%          array file is the expression values and in case of an
%          experiments description the effect values that correspond 
%          to the expression values in the same row.
% The nature of data depends on the settings in the definition file that
% was passed on to fspma.wrapper. Normally one assumes data on a logarithmic 
% scale (log ratios or log expression values) that was potentially normalized.
% It is thus of importance to consult the definition file to be certain about
% what was done to the data.
%
% (C) P. Sykacek 2006

% first we check the number of columns to construct the format strings then used to
% read the data.


fid=fopen(fname, 'rt');
fname
fid
hdrstr=fgets(fid);
%fclose(fid);

if hdrstr~=-1
    ids=[0, find(hdrstr==sprintf('\t')), length(hdrstr)];
    ncols=length(ids)-1;
    header=cell(1, ncols);
    for n=1:ncols
      header{n}=hdrstr(ids(n)+1:ids(n+1)-1);
    end
    % get rid of potential leftower in a bad Win32 to Unix crlf conversion. 
    header{ncols}=sscanf(header{ncols}, '%s ', 1);
end

% this header allows us now to construct the format string for textread and read in all data in the file
data_format=repmat('%f ', 1, ncols); % construct data format
%data_format(length(data_format))='\n';

[data, count]=fscanf(fid, data_format, [ncols, inf]);
data=data';
fclose(fid);