function [rankprc]=vals2rankprobs(data, sortorder)
% function [rankprc]=vals2rankprobs(data, sortorder) converts data into
% rank percentages. We assume that each column in data contains
% quantitative values that should be sorted w.r.t. sortorder. The function
% calculates which row positions in data appear at each rank and calculates
% thus for every rank position the fraction of row positions we find at
% that rank. 
% IN
% data:      A [npos x nsamples] matrix of data values with every column
%            representing a particular state to be ranked for (e.g. a
%            subsample of some data used for calculating a likelihood
%            score.) 
% sortorder: An optional order directive pased on to sort.
%
% OUT
% rankprc:  A [npos x npos] matrix of rank fractions. Column n contains for
%           all m rows the number of samples found in the corresponding data 
%           row ranked to that position. If we have for example
%           rankprc(5,1) == 1, we know that all columns in data have the
%           fifth row ranked top according to sortorder. rankprc allows
%           thus illustrating rank ambiguities. If for example the second 
%           rank after ordering w.r.t. sortorder is found in rows 2 and 3
%           in data, rankprc(2,2) and rankrpc(2,3) contain the fraction of
%           respective samples.
%
% (C) P. Sykacek 2008 <peter@sykacek.net>

if nargin < 2
    sortorder='descend';
end

[sd, id]=sort(data, sortorder);

nsample=size(data, 2);
npos=size(data, 1);
rankprc=zeros(npos, npos);
for rankpos=1:npos
    for rwpos=1:npos
        rankprc(rankpos, rwpos)=sum(id(rankpos,:)==rwpos)/nsample;
    end
end